@@ -6,6 +6,7 @@ import contextlib
 import uuid
 import time
 import re
+import socket
 
 import paramiko
 
@@ -17,6 +18,11 @@ from .io import IoHandler
 
 _ONE_MINUTE = 60
 
+
+class ConnectionError(Exception):
+    pass
+
+
 class SshShell(object):
     def __init__(self, hostname, username, password=None, port=22, private_key_file=None, connect_timeout=None):
         self._hostname = hostname
@@ -35,8 +41,7 @@ class SshShell(object):
         stderr = kwargs.pop("stderr", None)
         allow_error = kwargs.pop("allow_error", False)
         command_in_cwd = self._generate_run_command(*args, **kwargs)
-        client = self._connect_ssh()
-        channel = client.get_transport().open_session()
+        channel = self._get_ssh_transport().open_session()
         channel.exec_command(command_in_cwd)
         return SshProcess(
             channel,
@@ -89,14 +94,22 @@ class SshShell(object):
                 sftp.remove(remote_tarball_path)
                 
     def open(self, name, mode="r"):
-        client = self._connect_ssh()
-        sftp = client.open_sftp()
+        sftp = self._open_sftp_client()
         return SftpFile(sftp, sftp.open(name, mode))
                 
     @property
     def files(self):
         return FileOperations(self)
     
+    def _get_ssh_transport(self):
+        try:
+            return self._connect_ssh().get_transport()
+        except (socket.error, paramiko.SSHException, EOFError) as error:
+            raise ConnectionError(
+                "Error creating SSH connection\n" +
+                "Original error: {0}".format(error)
+            )
+    
     def _connect_ssh(self):
         if self._client is None:
             client = paramiko.SSHClient()
@@ -115,12 +128,14 @@ class SshShell(object):
     
     @contextlib.contextmanager
     def _connect_sftp(self):
-        client = self._connect_ssh()
-        sftp = client.open_sftp()
+        sftp = self._open_sftp_client()
         try:
             yield sftp
         finally:
             sftp.close()
+            
+    def _open_sftp_client(self):
+        return self._get_ssh_transport().open_sftp_client()
 
 
 class SftpFile(object):
